pub enum MulticallError {
InvalidChainId(u64),
TransportError(TransportError),
ContractError(Error),
FailedCall,
InvalidInitializationParams,
}Expand description
Errors when interacting with a Multicall contract.
Variants
InvalidChainId(u64)
Unsupported Chain ID used when creating the Multicall instance
TransportError(TransportError)
An error occurred interacting with a contract over RPC.
ContractError(Error)
Error when interacting with contracts. This is an error from the contract crate.
FailedCall
Multicall reverted due to an individual call failing.
InvalidInitializationParams
Attempted to initialize the Multicall instance with no address or chain ID